@@ -7,7 +7,6 @@ import re
 import warnings
 from collections import OrderedDict
 from typing import List, Optional
-from types import SimpleNamespace
 from typing import Dict, Set, Tuple
 
 import pandas.io.sql
@@ -22,6 +21,7 @@ import data_algebra.data_ops
 from data_algebra.OrderedSet import OrderedSet
 import data_algebra.op_catalog
 
+from data_algebra.sql_format_options import SQLFormatOptions
 
 # The db_model can be a bit tricky as SQL is represented a few ways depending
 # on how close to a final result we are.
@@ -32,48 +32,6 @@ import data_algebra.op_catalog
 # subordinate nodes.
 
 
-class SQLFormatOptions(SimpleNamespace):
-    """
-    Simple class for holding SQL formatting options
-    """
-
-    def __init__(
-        self,
-        use_with: bool = True,
-        annotate: bool = True,
-        sql_indent: str = " ",
-        initial_commas: bool = False,
-        warn_on_method_support: bool = True,
-        warn_on_novel_methods: bool = True,
-    ):
-        assert isinstance(use_with, bool)
-        assert isinstance(annotate, bool)
-        assert isinstance(sql_indent, str)
-        assert len(sql_indent) > 0
-        assert len(sql_indent.strip()) == 0
-        assert isinstance(initial_commas, bool)
-        SimpleNamespace.__init__(
-            self,
-            use_with=use_with,
-            annotate=annotate,
-            sql_indent=sql_indent,
-            initial_commas=initial_commas,
-            warn_on_method_support=warn_on_method_support,
-            warn_on_novel_methods=warn_on_novel_methods,
-        )
-
-    def __str__(self):
-        return self.__repr__()
-
-    # noinspection PyUnusedLocal
-    def _repr_pretty_(self, p, cycle):
-        """
-        IPython pretty print, used at implicit print time
-        https://ipython.readthedocs.io/en/stable/config/integrating.html
-        """
-        p.text(str(self))
-
-
 def _list_join_expecting_list(joiner: str, str_list: List[str]) -> List[str]:
     assert isinstance(joiner, str)
     assert isinstance(str_list, list)
@@ -88,6 +46,7 @@ def _clean_annotation(annotation: Optional[str]) -> Optional[str]:
         return annotation
     annotation = annotation.strip()
     annotation = re.sub(r"(\s|\r|\n)+", " ", annotation)
+    annotation = annotation.replace('%', "percent")  # SQL alchemy doesn't like these in comments
     return annotation.strip()
 
 
@@ -105,11 +64,43 @@ def _db_lag_expr(dbmodel, expression):
         elif periods < 0:
             return f"LEAD({arg_0}, {-periods})"
         else:
-            return f"{arg_0}"
+            raise ValueError("shift by zero not supported")
     else:
         raise ValueError("too many arguments to SQL LAG/LEAD")
 
 
+# Note, mod should not always equal remainder:
+# https://rob.conery.io/2018/08/21/mod-and-remainder-are-not-the-same/
+# But they do in numpy, which we will use as the
+# reference implementation.
+# import numpy as np
+# np.mod([5, 5, -5, 5], [2, -2, 2, -2])
+# # array([ 1, -1,  1, -1])
+# np.remainder([5, 5, -5, 5], [2, -2, 2, -2])
+# # array([ 1, -1,  1, -1])
+# so we are just going to send it out and use destination semantics
+def _db_mod_expr(dbmodel, expression):
+    return (
+        "MOD("
+        + dbmodel.expr_to_sql(expression.args[0], want_inline_parens=False)
+        + ", "
+        + dbmodel.expr_to_sql(expression.args[1], want_inline_parens=False)
+        + ")"
+    )
+
+
+# extend to floating point
+# import numpy as np
+# e0 = np.array([5, 5, -5, -5])
+# e1 = np.array([2, -2, 2, -2])
+# (e0 - np.floor(e0 / (1.0 * e1)) * e1)
+# # array([ 1., -1.,  1., -1.])
+def _db_remainder_expr(dbmodel, expression):
+    e0 = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    e1 = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
+    return f"({e0} - FLOOR({e0} / (1.0 * {e1})) * {e1})"
+
+
 def _db_mean_expr(dbmodel, expression):
     return (
         "AVG(" + dbmodel.expr_to_sql(expression.args[0], want_inline_parens=False) + ")"
@@ -129,30 +120,71 @@ def _db_is_null_expr(dbmodel, expression):
     )
 
 
-def _db_is_bad_expr(dbmodel, expression):
+def _db_is_inf_expr(dbmodel, expression):
+    subexpr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    plus_inf = f"CAST({dbmodel.value_to_sql('+infinity')} AS {dbmodel.float_type})"
+    minus_inf = f"CAST({dbmodel.value_to_sql('-infinity')} AS {dbmodel.float_type})"
+    return (
+            "(CASE"
+            + f' WHEN {subexpr} IS NULL THEN FALSE'
+            + f' WHEN NOT (({subexpr} > {minus_inf}) AND ({subexpr} < {plus_inf})) THEN TRUE'
+            + ' ELSE FALSE'
+            + ' END)'
+    )
+
+
+def _db_is_nan_expr(dbmodel, expression):
     subexpr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
     return (
-        "("
-        + subexpr
-        + " IS NULL OR "
-        + subexpr
-        + " >= "
-        + dbmodel.value_to_sql("+infinity")
-        + " OR "
-        + subexpr
-        + " <= "
-        + dbmodel.value_to_sql("-infinity")
-        + " OR ("
-        + subexpr
-        + " != 0 AND "
-        + subexpr
-        + " = -"
-        + subexpr
-        + "))"
+        "(CASE"
+        + f' WHEN {subexpr} IS NULL THEN TRUE'
+        + f' WHEN ({subexpr} > 0) AND (-{subexpr} > 0) THEN TRUE'
+        + f' WHEN ({subexpr} != {subexpr}) THEN TRUE'
+        + f' WHEN ({subexpr} != 0) AND ({subexpr} = -{subexpr}) THEN TRUE'
+        + ' ELSE FALSE'
+        + ' END)'
+    )
+
+
+def _db_is_bad_expr(dbmodel, expression):
+    subexpr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    plus_inf = f"CAST({dbmodel.value_to_sql('+infinity')} AS {dbmodel.float_type})"
+    minus_inf = f"CAST({dbmodel.value_to_sql('-infinity')} AS {dbmodel.float_type})"
+    return (
+        "(CASE"
+        + f' WHEN {subexpr} IS NULL THEN TRUE'
+        + f' WHEN ({subexpr} > 0) AND (-{subexpr} > 0) THEN TRUE'
+        + f' WHEN ({subexpr} != {subexpr}) THEN TRUE'
+        + f' WHEN ({subexpr} != 0) AND ({subexpr} = -{subexpr}) THEN TRUE'
+        + f' WHEN NOT (({subexpr} > {minus_inf}) AND ({subexpr} < {plus_inf})) THEN TRUE'
+        + ' ELSE FALSE'
+        + ' END)'
     )
 
 
 def _db_if_else_expr(dbmodel, expression):
+    assert len(expression.args)==3
+    if_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    x_expr = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
+    y_expr = dbmodel.expr_to_sql(expression.args[2], want_inline_parens=True)
+    return (
+            "CASE"
+            + " WHEN "
+            + if_expr
+            + " THEN "
+            + x_expr
+            + " WHEN NOT "
+            + if_expr
+            + " THEN "
+            + y_expr
+            + " ELSE "
+            + "NULL"
+            + " END"
+    )
+
+
+def _db_where_expr(dbmodel, expression):
+    assert len(expression.args)==3
     if_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
     x_expr = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
     y_expr = dbmodel.expr_to_sql(expression.args[2], want_inline_parens=True)
@@ -162,11 +194,9 @@ def _db_if_else_expr(dbmodel, expression):
         + if_expr
         + " THEN "
         + x_expr
-        + " WHEN NOT "
-        + if_expr
-        + " THEN "
+        + " ELSE "
         + y_expr
-        + " ELSE NULL END"
+        + " END"
     )
 
 
@@ -359,6 +389,15 @@ def _db_int_divide_expr(dbmodel, expression):
     return dbmodel.expr_to_sql(ratio, want_inline_parens=False)
 
 
+def _db_float_divide_expr(dbmodel, expression):
+    # don't issue an error
+    # https://cloud.google.com/bigquery/docs/reference/standard-sql/mathematical_functions#ieee_divide
+    assert len(expression.args) == 2
+    e0 = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    e1 = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
+    return f'({e0} / (1.0 * {e1}))'
+
+
 def _db_nunique_expr(dbmodel, expression):
     return (
         "COUNT(DISTINCT ("
@@ -408,15 +447,19 @@ def _trimstr(dbmodel, expression):
 
 
 def _any_expr(dbmodel, expression):
-    derived = expression.args[0].max() >= data_algebra.expr_rep.Value(1)
+    derived = expression.args[0].where(1, 0).max() >= data_algebra.expr_rep.Value(1)
     return dbmodel.expr_to_sql(derived, want_inline_parens=True)
 
 
 def _all_expr(dbmodel, expression):
-    derived = expression.args[0].min() >= data_algebra.expr_rep.Value(1)
+    derived = expression.args[0].where(1, 0).min() >= data_algebra.expr_rep.Value(1)
     return dbmodel.expr_to_sql(derived, want_inline_parens=True)
 
 
+def _any_value_expr(dbmodel, expression):
+    return 'MAX(' + dbmodel.expr_to_sql(expression.args[0], want_inline_parens=False) + ')'
+
+
 # date/time fns
 
 def _datetime_to_date(dbmodel, expression):
@@ -550,11 +593,14 @@ def _base_Sunday(dbmodel, expression):
 
 db_expr_formatters = {
     "shift": _db_lag_expr,
+    "is_inf": _db_is_inf_expr,
+    "is_nan": _db_is_nan_expr,
     "is_null": _db_is_null_expr,
     "is_bad": _db_is_bad_expr,
     "mean": _db_mean_expr,
     "size": _db_size_expr,
     "if_else": _db_if_else_expr,
+    "where": _db_where_expr,
     "is_in": _db_is_in_expr,
     "maximum": _db_maximum_expr,
     "fmax": _db_fmax_expr,
@@ -568,15 +614,20 @@ db_expr_formatters = {
     "floor": _db_floor_expr,
     "ceil": _db_ceil_expr,
     "//": _db_int_divide_expr,
+    '%/%': _db_float_divide_expr,
     "**": _db_pow_expr,
     "nunique": _db_nunique_expr,
     "mapv": _db_mapv,
+    "%": _db_mod_expr,
+    "mod": _db_mod_expr,
+    "remainder": _db_remainder_expr,
     # additional fns
     "as_int64": _as_int64,
     "as_str": _as_str,
     "trimstr": _trimstr,
     "any": _any_expr,
     "all": _all_expr,
+    "any_value": _any_value_expr,
     "datetime_to_date": _datetime_to_date,
     "parse_datetime": _parse_datetime,
     "parse_date": _parse_date,
@@ -631,7 +682,7 @@ def _annotated_method_catalogue(
     for i in range(data_algebra.op_catalog.methods_table.shape[0]):
         row = data_algebra.op_catalog.methods_table.loc[i, :]
         matches = []
-        if row['op_class'] == 'p':
+        if row['op_class'] in {'p', 'up'}:
             matches.append(data_algebra.data_ops_types.MethodUse(
                 row['op'],
                 is_project=True,
@@ -652,7 +703,7 @@ def _annotated_method_catalogue(
                 is_windowed=True,
                 is_ordered=True,
             ))
-        else:
+        else:  # e and u case
             matches.append(data_algebra.data_ops_types.MethodUse(
                 row['op'],
                 is_project=False,
@@ -682,6 +733,7 @@ class DBModel:
     drop_text: str
     string_type: str
     supports_with: bool
+    supports_cte_elim: bool
     allow_extend_merges: bool
     default_SQL_format_options: SQLFormatOptions
     union_all_term_start: str
@@ -702,7 +754,9 @@ class DBModel:
         on_joiner: str = "AND",
         drop_text: str = "DROP TABLE",
         string_type: str = "VARCHAR",
+        float_type: str = 'FLOAT64',
         supports_with: bool = True,
+        supports_cte_elim: bool = True,
         allow_extend_merges: bool = True,
         default_SQL_format_options=None,
         union_all_term_start: str = "(",
@@ -728,11 +782,13 @@ class DBModel:
         self.on_joiner = on_joiner
         self.drop_text = drop_text
         self.string_type = string_type
+        self.float_type = float_type
         if default_SQL_format_options is None:
             default_SQL_format_options = SQLFormatOptions()
         assert isinstance(default_SQL_format_options, SQLFormatOptions)
         self.default_SQL_format_options = default_SQL_format_options
         self.supports_with = supports_with
+        self.supports_cte_elim = supports_cte_elim and supports_with
         self.allow_extend_merges = allow_extend_merges
         self.union_all_term_start = union_all_term_start
         self.union_all_term_end = union_all_term_end
@@ -1057,7 +1113,6 @@ class DBModel:
         if len(missing) > 0:
             raise KeyError("referred to unknown columns: " + str(missing))
         cols_using = [c for c in table_def.column_names if c in using]
-
         subsql = data_algebra.near_sql.NearSQLTable(
             terms={k: self.quote_identifier(k) for k in cols_using},
             table_name=self.quote_table_name(table_def),
@@ -1078,6 +1133,7 @@ class DBModel:
                 query_name=view_name,
                 quoted_query_name=self.quote_identifier(view_name),
                 sub_sql=subsql.to_bound_near_sql(columns=using),
+                ops_key=f"table({table_def.table_name}, {terms.keys()})",
             )
         return near_sql
 
@@ -1221,6 +1277,7 @@ class DBModel:
             annotation=annotation,
             mergeable=True,
             declared_term_dependencies=declared_term_dependencies,
+            ops_key=f"extend({extend_node}, {terms.keys()})",
         )
         return near_sql
 
@@ -1262,6 +1319,7 @@ class DBModel:
             annotation=str(
                 project_node.to_python_src_(print_sources=False, indent=-1)
             ),
+            ops_key=f"project({project_node}, {terms.keys()})",
         )
         return near_sql
 
@@ -1308,6 +1366,7 @@ class DBModel:
                     print_sources=False, indent=-1
                 )
             ),
+            ops_key=f"select({select_rows_node}, {terms.keys()})",
         )
         return near_sql
 
@@ -1430,6 +1489,7 @@ class DBModel:
             annotation=str(
                 order_node.to_python_src_(print_sources=False, indent=-1)
             ),
+            ops_key=f"order({order_node})",  # no terms
         )
         return near_sql
 
@@ -1469,10 +1529,11 @@ class DBModel:
             annotation=str(
                 rename_node.to_python_src_(print_sources=False, indent=-1)
             ),
+            ops_key=f"rename({rename_node}, {terms.keys()})",
         )
         return near_sql
 
-    def _coalesce_terms(self, *, sub_view_name_first, sub_view_name_second, cols):
+    def _coalesce_terms(self, *, sub_view_name_first, sub_view_name_second, cols) -> OrderedDict:
         coalesce_formatter = self.sql_formatters["coalesce"]
 
         class PseudoExpression:
@@ -1482,8 +1543,9 @@ class DBModel:
             def __init__(self, args):
                 self.args = args.copy()
 
-        terms = {
-            ci: coalesce_formatter(
+        terms = OrderedDict()
+        for ci in cols:
+            terms[ci] = coalesce_formatter(
                 self,
                 PseudoExpression(
                     [
@@ -1492,18 +1554,23 @@ class DBModel:
                     ]
                 ),
             )
-            for ci in cols
-        }
         return terms
 
-    def _natural_join_sub_queries(self, *, join_node, using, temp_id_source):
+    def _natural_join_sub_queries(
+            self, 
+            *, 
+            join_node, 
+            using,
+            temp_id_source: List
+    ) -> Tuple[OrderedSet, data_algebra.near_sql.NearSQL,
+               OrderedSet, data_algebra.near_sql.NearSQL]:
         if join_node.node_name != "NaturalJoinNode":
             raise TypeError(
                 "Expected join_node to be a data_algebra.data_ops.NaturalJoinNode)"
             )
         if using is None:
             using = OrderedSet(join_node.column_names)
-        by_set = set(join_node.by)
+        by_set = OrderedSet(join_node.by)
         if len(using) < 1:
             raise ValueError("join must use or select at least one column")
         missing = using - set(join_node.column_names)
@@ -1536,35 +1603,43 @@ class DBModel:
             temp_id_source = [0]
         if using is None:
             using = OrderedSet(join_node.column_names)
+        view_name = f"natural_join_{temp_id_source[0]}"
+        left_q = f"join_source_left_{temp_id_source[0]}"
+        right_q = f"join_source_right_{temp_id_source[0]}"
+        temp_id_source[0] = temp_id_source[0] + 1
         using_left, sql_left, using_right, sql_right = self._natural_join_sub_queries(
             join_node=join_node, using=using, temp_id_source=temp_id_source
         )
-        view_name = "natural_join_" + str(temp_id_source[0])
-        temp_id_source[0] = temp_id_source[0] + 1
+        left_qqn = self.quote_identifier(left_q)
+        right_qqn = self.quote_identifier(right_q)
         common = using_left.intersection(using_right)
         if left_is_first:
             terms = self._coalesce_terms(
-                sub_view_name_first=sql_left.quoted_query_name,
-                sub_view_name_second=sql_right.quoted_query_name,
+                sub_view_name_first=left_qqn,
+                sub_view_name_second=right_qqn,
                 cols=[ci for ci in common if ci in using],
             )
         else:
             terms = self._coalesce_terms(
-                sub_view_name_first=sql_right.quoted_query_name,
-                sub_view_name_second=sql_left.quoted_query_name,
+                sub_view_name_first=right_qqn,
+                sub_view_name_second=left_qqn,
                 cols=[ci for ci in common if ci in using],
             )
-        terms.update({ci: None for ci in using_left - common})
-        terms.update({ci: None for ci in using_right - common})
+        for ci in using_left:
+            if ci not in common:
+                terms[ci] = None
+        for ci in using_right:
+            if ci not in common:
+                terms[ci] = None
         on_terms = []
         if len(join_node.by) > 0:
             on_terms = ["ON " + self.on_start] + self._indent_and_sep_terms(
                 [
-                    sql_left.quoted_query_name
+                    left_qqn
                     + "."
                     + self.quote_identifier(c)
                     + " = "
-                    + sql_right.quoted_query_name
+                    + right_qqn
                     + "."
                     + self.quote_identifier(c)
                     for c in join_node.by
@@ -1578,13 +1653,22 @@ class DBModel:
             terms=terms,
             query_name=view_name,
             quoted_query_name=self.quote_identifier(view_name),
-            sub_sql1=sql_left.to_bound_near_sql(columns=using_left, force_sql=False),
+            sub_sql1=sql_left.to_bound_near_sql(
+                columns=using_left,
+                force_sql=False,
+                public_name=left_q,
+                public_name_quoted=left_qqn),
             joiner=join_node.jointype + " JOIN",
-            sub_sql2=sql_right.to_bound_near_sql(columns=using_right, force_sql=False),
+            sub_sql2=sql_right.to_bound_near_sql(
+                columns=using_right,
+                force_sql=False,
+                public_name=right_q,
+                public_name_quoted=right_qqn),
             suffix=on_terms,
             annotation=str(
                 join_node.to_python_src_(print_sources=False, indent=-1)
             ),
+            ops_key=f"join({join_node}, {terms.keys()})",
         )
         return near_sql
 
@@ -1612,39 +1696,36 @@ class DBModel:
         using_right = subusing[1]
         if set(using_left) != set(using_right):
             raise ValueError("left/right usings did not match")
-        sql_left = concat_node.sources[0].to_near_sql_implementation_(
-            db_model=self, using=using_left, temp_id_source=temp_id_source
+        using_joint = using_left.copy()
+        terms = {ci: None for ci in using_joint}
+        expr_left = concat_node.sources[0]
+        expr_right = concat_node.sources[1]
+        if concat_node.id_column is not None:
+            expr_left = expr_left.extend({concat_node.id_column: f'"{concat_node.a_name}"'})
+            expr_right = expr_right.extend({concat_node.id_column: f'"{concat_node.b_name}"'})
+            using_joint.add(concat_node.id_column)
+            terms.update({concat_node.id_column: None})
+        sql_left = expr_left.to_near_sql_implementation_(
+            db_model=self, using=using_joint, temp_id_source=temp_id_source
         )
-        sql_right = concat_node.sources[1].to_near_sql_implementation_(
-            db_model=self, using=using_left, temp_id_source=temp_id_source
+        sql_right = expr_right.to_near_sql_implementation_(
+            db_model=self, using=using_joint, temp_id_source=temp_id_source
         )
         view_name = "concat_rows_" + str(temp_id_source[0])
         temp_id_source[0] = temp_id_source[0] + 1
-        terms = {ci: None for ci in using_left}
-        constants_left = None
-        constants_right = None
-        if concat_node.id_column is not None:
-            constants_left = {
-                concat_node.id_column: self.quote_string(concat_node.a_name)
-            }
-            constants_right = {
-                concat_node.id_column: self.quote_string(concat_node.b_name)
-            }
-            terms.update({concat_node.id_column: None})
         near_sql = data_algebra.near_sql.NearSQLBinaryStep(
             terms=terms,
             query_name=view_name,
             quoted_query_name=self.quote_identifier(view_name),
             sub_sql1=sql_left.to_bound_near_sql(
-                columns=using_left, force_sql=True, constants=constants_left,
-            ),
+                columns=using_joint.copy(), force_sql=True),
             joiner="UNION ALL",
             sub_sql2=sql_right.to_bound_near_sql(
-                columns=using_left, force_sql=True, constants=constants_right,
-            ),
+                columns=using_joint.copy(), force_sql=True),
             annotation=str(
                 concat_node.to_python_src_(print_sources=False, indent=-1)
             ),
+            ops_key=f"concat({concat_node}, {terms.keys()})",
         )
         return near_sql
 
@@ -1677,6 +1758,10 @@ class DBModel:
             sql_format_options: Optional[SQLFormatOptions] = None) -> str:
         """
         Convert ViewRepresentation into SQL string.
+
+        :param ops: ViewRepresentation to convert
+        :param sql_format_options: sql formatting options
+        :return: sql string
         """
         assert isinstance(self, DBModel)
         assert isinstance(ops, data_algebra.data_ops.ViewRepresentation)
@@ -1692,6 +1777,7 @@ class DBModel:
             non_rec = self.non_recommended_methods(ops)
             if len(non_rec) > 0:
                 warnings.warn(f"{self} translation doesn't fully support method context: {non_rec}", UserWarning)
+        # TODO: put common sub-expression control object here and pass into converters
         temp_id_source = [0]
         near_sql = ops.to_near_sql_implementation_(
             db_model=self, using=None, temp_id_source=temp_id_source
@@ -1699,14 +1785,17 @@ class DBModel:
         assert isinstance(near_sql, data_algebra.near_sql.NearSQL)
         sql_str_list = None
         if sql_format_options.use_with and self.supports_with:
-            sequence = near_sql.to_with_form()
+            cte_cache: Optional[Dict] = None
+            if sql_format_options.use_cte_elim and self.supports_with and self.supports_cte_elim:
+                cte_cache = dict()
+            sequence = near_sql.to_with_form(cte_cache=cte_cache)
             len_sequence = len(sequence.previous_steps)
             # can fall back to the non-with path
             if len(sequence.previous_steps) >= 1:
                 sql_sequence: List[str] = []
                 for i in range(len_sequence):
                     nmi = sequence.previous_steps[i][0]  # already quoted
-                    sqli = sequence.previous_steps[i][1].to_sql_str_list(
+                    sqli = sequence.previous_steps[i][1].convert_subsql(
                         db_model=self, sql_format_options=sql_format_options
                     )
                     sql_sequence = (
@@ -1740,7 +1829,7 @@ class DBModel:
             model_descr = re.sub(r"\s+", " ", str(self))
             sql_str_list = [
                 f"-- data_algebra SQL https://github.com/WinVector/data_algebra",
-                f"--  dialect: {model_descr}",
+                f"--  dialect: {model_descr} {data_algebra.__version__}",
                 f"--       string quote: {self.string_quote}",
                 f"--   identifier quote: {self.identifier_quote}",
             ] + sql_str_list
@@ -1904,45 +1993,12 @@ class DBModel:
             return self.quote_identifier(k)
         return v + " AS " + self.quote_identifier(k)
 
-    def convert_nearsql_container_subsql_(
-        self, nearsql_container, *, sql_format_options=None
-    ) -> List[str]:
-        """
-        Convert sub-SQL into list of SQL string lines.
-        """
-        assert isinstance(nearsql_container, data_algebra.near_sql.NearSQLContainer)
-        if sql_format_options is None:
-            sql_format_options = self.default_SQL_format_options
-        assert isinstance(sql_format_options, SQLFormatOptions)
-        sub_sql = nearsql_container.to_sql_str_list(
-            self, sql_format_options=sql_format_options
-        )
-        assert isinstance(sub_sql, list)
-        if isinstance(nearsql_container.near_sql, data_algebra.near_sql.NearSQLTable):
-            sql = sub_sql
-            if (
-                nearsql_container.near_sql.quoted_query_name
-                != nearsql_container.near_sql.quoted_table_name
-            ):
-                sql = sql + [nearsql_container.near_sql.quoted_query_name]
-        elif isinstance(
-            nearsql_container.near_sql,
-            data_algebra.near_sql.NearSQLCommonTableExpression,
-        ):
-            sql = sub_sql
-        else:
-            sql = (
-                ["("] + sub_sql + [") " + nearsql_container.near_sql.quoted_query_name]
-            )
-        return sql
-
     def nearsqlcte_to_sql_str_list_(
         self,
         near_sql,
         *,
         columns=None,
         force_sql=False,
-        constants=None,
         sql_format_options=None,
     ) -> List[str]:
         """
@@ -1967,7 +2023,6 @@ class DBModel:
         *,
         columns=None,
         force_sql=False,
-        constants=None,
         sql_format_options=None,
     ) -> List[str]:
         """
@@ -1984,14 +2039,8 @@ class DBModel:
                 columns = []
         if len(columns) <= 0:
             columns = []
-        have_constants = (constants is not None) and (len(constants) > 0)
-        if force_sql or have_constants:
+        if force_sql:
             terms_strs = [self.quote_identifier(k) for k in columns]
-            if have_constants:
-                terms_strs = terms_strs + [
-                    v + " AS " + self.quote_identifier(k)
-                    for (k, v) in constants.items()
-                ]
             if len(terms_strs) < 1:
                 terms_strs = ["*"]
             return (
@@ -2010,7 +2059,6 @@ class DBModel:
         *,
         columns=None,
         force_sql=False,
-        constants=None,
         sql_format_options=None,
     ) -> List[str]:
         """
@@ -2026,11 +2074,6 @@ class DBModel:
             if columns is None:
                 columns = [k for k in terms.keys()]
             terms_strs = [self.enc_term_(k, terms=terms) for k in columns]
-            if (constants is not None) and (len(constants) > 0):
-                terms_strs = terms_strs + [
-                    v + " AS " + self.quote_identifier(k)
-                    for (k, v) in constants.items()
-                ]
             if len(terms_strs) < 1:
                 terms_strs = ["*"]
         sql_start = "SELECT"
@@ -2051,7 +2094,9 @@ class DBModel:
             + [
                 sql_format_options.sql_indent + si
                 for si in near_sql.sub_sql.convert_subsql(
-                    db_model=self, sql_format_options=sql_format_options
+                    db_model=self,
+                    sql_format_options=sql_format_options,
+                    quoted_query_name_annotation=near_sql.sub_sql.near_sql.quoted_query_name
                 )
             ]
         )
@@ -2081,7 +2126,9 @@ class DBModel:
             sql = sql + [
                 sql_format_options.sql_indent + si
                 for si in near_sql.sub_sql.convert_subsql(
-                    db_model=self, sql_format_options=sql_format_options
+                    db_model=self,
+                    sql_format_options=sql_format_options,
+                    quoted_query_name_annotation=near_sql.sub_sql.near_sql.quoted_query_name
                 )
             ]
         if (near_sql.suffix is not None) and (len(near_sql.suffix) > 0):
@@ -2094,7 +2141,6 @@ class DBModel:
         *,
         columns=None,
         force_sql=False,
-        constants=None,
         sql_format_options=None,
         quoted_query_name=None,
     ) -> List[str]:
@@ -2111,8 +2157,6 @@ class DBModel:
             terms = near_sql.terms
         if columns is None:
             columns = [k for k in terms.keys()]
-        if (constants is not None) and (len(constants) > 0):
-            terms.update(constants)
         terms_strs = [self.enc_term_(k, terms=terms) for k in columns]
         if len(terms_strs) < 1:
             terms_strs = ["*"]
@@ -2126,20 +2170,17 @@ class DBModel:
             clean_anno = _clean_annotation(near_sql.annotation)
             if clean_anno is not None:
                 sql_start = "SELECT  -- " + clean_anno
-        if is_union:
-            substr_1 = near_sql.sub_sql1.to_sql_str_list(
-                db_model=self, sql_format_options=sql_format_options
-            )
-            substr_2 = near_sql.sub_sql2.to_sql_str_list(
-                db_model=self, sql_format_options=sql_format_options
-            )
-        else:
-            substr_1 = near_sql.sub_sql1.convert_subsql(
-                db_model=self, sql_format_options=sql_format_options
-            )
-            substr_2 = near_sql.sub_sql2.convert_subsql(
-                db_model=self, sql_format_options=sql_format_options
-            )
+        subsql_add_query_name = not is_union
+        substr_1 = near_sql.sub_sql1.convert_subsql(
+            db_model=self,
+            sql_format_options=sql_format_options,
+            quoted_query_name_annotation=near_sql.sub_sql1.public_name_quoted if subsql_add_query_name else None
+        )
+        substr_2 = near_sql.sub_sql2.convert_subsql(
+            db_model=self,
+            sql_format_options=sql_format_options,
+            quoted_query_name_annotation=near_sql.sub_sql2.public_name_quoted if subsql_add_query_name else None
+        )
         sql = (
             [sql_start]
             + self._indent_and_sep_terms(
@@ -2158,7 +2199,7 @@ class DBModel:
             and (quoted_query_name is not None)
             and (len(quoted_query_name) > 0)
         ):
-            sql = sql + [") " + quoted_query_name]
+            sql = sql + [") " + quoted_query_name]  # duplicate name, but not of whole query
         else:
             sql = sql + [")"]
         return sql
