@@ -10,6 +10,7 @@ methods_table = pd.DataFrame(
         "op": [
             "!=",
             "%",
+            "%/%",
             "*",
             "**",
             "+",
@@ -62,6 +63,8 @@ methods_table = pd.DataFrame(
             "if_else",
             "is_bad",
             "is_in",
+            "is_inf",
+            "is_nan",
             "is_null",
             "log",
             "log10",
@@ -87,12 +90,11 @@ methods_table = pd.DataFrame(
             "timestamp_diff",
             "trimstr",
             "weekofyear",
+            "where",
             "year",
             "_count",
             "_ngroup",
             "_size",
-            "all",
-            "any",
             "count",
             "max",
             "mean",
@@ -117,6 +119,7 @@ methods_table = pd.DataFrame(
             "sum",
             "var",
             "_uniform",
+            "any_value",
             "_row_number",
             "bfill",
             "cumcount",
@@ -125,6 +128,7 @@ methods_table = pd.DataFrame(
             "cumprod",
             "cumsum",
             "ffill",
+            "first",
             "last",
             "rank",
             "shift",
@@ -132,6 +136,7 @@ methods_table = pd.DataFrame(
         "expression": [
             "x != y",
             "row_id % q",
+            "x %/% y",
             "x * y",
             "x ** y",
             "x + y",
@@ -184,6 +189,8 @@ methods_table = pd.DataFrame(
             "a.if_else(x, y)",
             "z.is_bad()",
             "row_id.is_in({1, 3})",
+            "y.is_inf()",
+            "y.is_nan()",
             "z.is_null()",
             "x.log()",
             "x.log10()",
@@ -191,14 +198,14 @@ methods_table = pd.DataFrame(
             'g.mapv({"a": 1, "b": 2, "z": 26}, 0)',
             "row_id.maximum(x)",
             "row_id.minimum(x)",
-            "y.mod(0.5)",
+            "row_id.mod(2)",
             "date_col_0.month()",
             "a or b",
             "a | b",
             "str_date_col.parse_date()",
             "str_datetime_col.parse_datetime()",
             "date_col_0.quarter()",
-            "y.remainder(0.5)",
+            "row_id.remainder(2)",
             "y.round()",
             "z.sign()",
             "x.sin()",
@@ -209,12 +216,11 @@ methods_table = pd.DataFrame(
             "datetime_col_0.timestamp_diff(datetime_col_1)",
             "g.trimstr(0, 2)",
             "date_col_0.weekofyear()",
+            "a.where(x, y)",
             "date_col_0.year()",
             "_count()",
             "_ngroup()",
             "_size()",
-            "a.all()",
-            "a.any()",
             "z.count()",
             "x.max()",
             "x.mean()",
@@ -239,6 +245,7 @@ methods_table = pd.DataFrame(
             "x.sum()",
             "x.var()",
             "_uniform()",
+            "x.any_value()",
             "_row_number()",
             "z.bfill()",
             "z.cumcount()",
@@ -247,6 +254,7 @@ methods_table = pd.DataFrame(
             "x.cumprod()",
             "x.cumsum()",
             "z.ffill()",
+            "x.first()",
             "x.last()",
             "x.rank()",
             "x.shift()",
@@ -332,8 +340,10 @@ methods_table = pd.DataFrame(
             "e",
             "e",
             "e",
-            "g",
-            "g",
+            "e",
+            "e",
+            "e",
+            "e",
             "g",
             "g",
             "g",
@@ -361,6 +371,8 @@ methods_table = pd.DataFrame(
             "p",
             "p",
             "u",
+            "up",
+            "w",
             "w",
             "w",
             "w",
@@ -494,6 +506,10 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
+            "y",
+            "y",
+            "y",
         ],
         "SQLiteModel": [
             "y",
@@ -519,6 +535,7 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "n",
             "y",
             "y",
@@ -558,13 +575,15 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
+            "y",
             "n",
             "y",
             "y",
             "n",
             "n",
             "n",
-            "w",
+            "y",
             "y",
             "y",
             "y",
@@ -575,12 +594,11 @@ methods_table = pd.DataFrame(
             "n",
             "y",
             "n",
+            "y",
             "n",
             "w",
             "n",
             "y",
-            "n",
-            "n",
             "y",
             "y",
             "y",
@@ -606,6 +624,7 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "n",
             "n",
             "n",
@@ -615,11 +634,13 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "n",
+            "n",
             "y",
         ],
         "BigQueryModel": [
             "y",
-            "n",
+            "y",
+            "y",
             "y",
             "y",
             "y",
@@ -675,15 +696,6 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
-            "n",
-            "y",
-            "y",
-            "y",
-            "n",
-            "y",
-            "y",
-            "y",
-            "y",
             "y",
             "y",
             "n",
@@ -698,11 +710,26 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
             "w",
             "n",
             "y",
-            "n",
-            "n",
+            "y",
+            "y",
+            "y",
+            "y",
+            "y",
             "y",
             "y",
             "y",
@@ -714,13 +741,9 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "n",
-            "n",
             "y",
             "y",
             "y",
-            "n",
-            "y",
-            "y",
             "y",
             "y",
             "y",
@@ -737,11 +760,13 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "n",
+            "n",
             "y",
         ],
         "PostgreSQLModel": [
             "y",
-            "n",
+            "y",
+            "y",
             "y",
             "y",
             "y",
@@ -766,7 +791,7 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "y",
-            "n",
+            "y",
             "y",
             "n",
             "y",
@@ -797,18 +822,20 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
-            "n",
-            "y",
             "y",
             "y",
             "n",
             "y",
             "y",
             "y",
+            "y",
+            "y",
+            "y",
+            "y",
             "n",
             "n",
             "y",
-            "n",
+            "y",
             "y",
             "y",
             "y",
@@ -820,11 +847,10 @@ methods_table = pd.DataFrame(
             "y",
             "w",
             "y",
+            "y",
             "w",
             "n",
             "y",
-            "n",
-            "n",
             "y",
             "y",
             "y",
@@ -835,8 +861,8 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
-            "n",
-            "n",
+            "y",
+            "y",
             "y",
             "y",
             "y",
@@ -850,6 +876,7 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "n",
             "n",
             "n",
@@ -859,6 +886,7 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "n",
+            "n",
             "y",
         ],
         "SparkSQLModel": [
@@ -880,6 +908,7 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "n",
             "n",
             "n",
@@ -916,6 +945,8 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
+            "y",
             "w",
             "y",
             "y",
@@ -930,7 +961,7 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "y",
-            "n",
+            "y",
             "y",
             "y",
             "y",
@@ -942,11 +973,10 @@ methods_table = pd.DataFrame(
             "y",
             "w",
             "y",
+            "y",
             "w",
             "n",
             "y",
-            "n",
-            "n",
             "w",
             "y",
             "y",
@@ -957,8 +987,8 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
-            "n",
-            "n",
+            "y",
+            "y",
             "w",
             "y",
             "y",
@@ -972,6 +1002,7 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "n",
             "n",
             "n",
@@ -979,13 +1010,15 @@ methods_table = pd.DataFrame(
             "n",
             "y",
             "n",
+            "y",
             "w",
             "y",
             "y",
         ],
         "MySQLModel": [
             "y",
-            "n",
+            "y",
+            "y",
             "y",
             "y",
             "y",
@@ -1038,6 +1071,8 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "n",
+            "y",
             "y",
             "y",
             "y",
@@ -1052,7 +1087,7 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "y",
-            "n",
+            "y",
             "y",
             "y",
             "y",
@@ -1064,11 +1099,10 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "w",
             "n",
             "y",
-            "n",
-            "n",
             "y",
             "y",
             "y",
@@ -1094,6 +1128,7 @@ methods_table = pd.DataFrame(
             "y",
             "y",
             "y",
+            "y",
             "n",
             "n",
             "n",
@@ -1103,129 +1138,134 @@ methods_table = pd.DataFrame(
             "n",
             "n",
             "n",
+            "n",
             "y",
         ],
         "version": [
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
-            "1.3.0",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
+            "1.3.3",
         ],
     }
 )
