@@ -96,6 +96,7 @@ def _type_safe_not_equal(a, b):
 
 
 def _type_safe_is_in(a, b):
+    b = list(b)
     if len(b) > 0:
         type_a = data_algebra.util.guess_carried_scalar_type(a)
         type_b = {data_algebra.util.map_type_to_canonical(type(v)) for v in b}
@@ -107,7 +108,8 @@ def _type_safe_is_in(a, b):
     return numpy.isin(a, b)
 
 
-def _map_v(a, value_map, default_value):
+def _map_v(a, value_map, default_value=None):
+    """Map values to values."""
     if len(value_map) > 0:
         type_a = data_algebra.util.guess_carried_scalar_type(a)
         type_k = {
@@ -124,9 +126,10 @@ def _map_v(a, value_map, default_value):
         if not data_algebra.util.compatible_types(type_v):
             raise TypeError(f"multiple types in dictionary values: {type_v} in mapv()")
         type_v = list(type_v)[0]
-        type_d = data_algebra.util.guess_carried_scalar_type(default_value)
-        if not data_algebra.util.compatible_types([type_d, type_v]):
-            raise TypeError(f"default is {type_d} for {type_v} values in mapv()'s")
+        if default_value is not None:
+            type_d = data_algebra.util.guess_carried_scalar_type(default_value)
+            if not data_algebra.util.compatible_types([type_d, type_v]):
+                raise TypeError(f"default is {type_d} for {type_v} values in mapv()'s")
     # https://pandas.pydata.org/docs/reference/api/pandas.Series.map.html
     a = data_algebra.default_data_model.pd.Series(a)
     a = a.map(value_map, na_action="ignore")
@@ -162,6 +165,32 @@ def _k_mul(*args):
     return res
 
 
+def _where_expr(*args):
+    """
+    where(cond, a, b) returns a for positions where cond is True, b otherwise (including cond None).
+    """
+    assert len(args) == 3
+    cond = args[0]
+    a = args[1]
+    b = args[2]
+    return numpy.where(cond, a, b)
+
+
+def _if_else_expr(*args):
+    """
+    if_else(cond, a, b) returns a for positions where cond is True, b when cond is False, None otherwise.
+    """
+    assert len(args) == 3
+    cond = args[0]
+    a = args[1]
+    b = args[2]
+    res = numpy.where(cond, a, b)
+    bad_posns = data_algebra.default_data_model.bad_column_positions(cond)
+    if numpy.any(bad_posns):
+        res[bad_posns] = None
+    return res
+
+
 def populate_impl_map(data_model) -> Dict[str, Callable]:
     """
     Map symbols to implementations.
@@ -181,6 +210,7 @@ def populate_impl_map(data_model) -> Dict[str, Callable]:
         "*": _k_mul,
         "/": numpy.divide,
         "//": numpy.floor_divide,
+        "%/%": numpy.divide,
         "%": numpy.mod,
         "**": numpy.power,
         "and": _k_and,
@@ -193,7 +223,10 @@ def populate_impl_map(data_model) -> Dict[str, Callable]:
         "^": numpy.logical_xor,
         "not": numpy.logical_not,
         "!": numpy.logical_not,
-        "if_else": numpy.where,
+        "where": _where_expr,
+        "if_else": _if_else_expr,
+        "is_nan": data_model.isnan,
+        "is_inf": data_model.isinf,
         "is_null": data_model.isnull,
         "is_bad": data_model.bad_column_positions,
         "is_in": _type_safe_is_in,
@@ -268,6 +301,7 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
 
     pd: types.ModuleType
     impl_map: Dict[str, Callable]
+    transform_op_map: Dict[str, str]
     user_fun_map: Dict[str, Callable]
     _method_dispatch_table: Dict[str, Callable]
 
@@ -278,6 +312,9 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
         )
         self.pd = pd
         self.impl_map = populate_impl_map(data_model=self)
+        self.transform_op_map = {
+            'any_value': 'first'
+        }
         self.user_fun_map = dict()
         self._method_dispatch_table = {
             "ConcatRowsNode": self.concat_rows_step,
@@ -338,12 +375,26 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
         """
         return self.pd.isnull(x)
 
+    def isnan(self, x):
+        """
+        Return vector indicating which entries are nan (vectorized).
+        """
+        x = numpy.asarray(x + 0.0, dtype=float)
+        return numpy.isnan(x)
+
+    def isinf(self, x):
+        """
+        Return vector indicating which entries are nan (vectorized).
+        """
+        x = numpy.asarray(x + 0.0, dtype=float)
+        return numpy.isinf(x)
+
     def bad_column_positions(self, x):
         """
         Return vector indicating which entries are bad (null or nan) (vectorized).
         """
         if self.can_convert_col_to_numeric(x):
-            x = numpy.asarray(x + 0, dtype=float)
+            x = numpy.asarray(x + 0.0, dtype=float)
             return numpy.logical_or(
                 self.pd.isnull(x), numpy.logical_or(numpy.isnan(x), numpy.isinf(x))
             )
@@ -410,7 +461,14 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
             except TypeError:
                 target_rows = max(target_rows, 1)  # scalar
         if target_rows < 1:
-            return self.pd.DataFrame(cols)
+            # noinspection PyBroadException
+            try:
+                res = self.pd.DataFrame(cols)
+                if res.shape[0] > 0:
+                    res = res.loc[[False] * res.shape[0], :].reset_index(drop=True, inplace=False)
+            except Exception:
+                res = self.pd.DataFrame({k: [] for k in cols.keys()})
+            return res
 
         # agg can return scalars, which then can't be made into a self.pd.DataFrame
         def promote_scalar(vi, *, target_len):
@@ -563,8 +621,13 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
                     elif zero_op in {"ngroup"}:
                         subframe[k] = opframe.ngroup()
                     elif zero_op in {"size"}:
+                        transform_op = zero_op
+                        try:
+                            transform_op = self.transform_op_map[transform_op]
+                        except KeyError:
+                            pass
                         subframe[k] = opframe[standin_name].transform(
-                            zero_op
+                            transform_op
                         )  # Pandas transform, not data_algebra
                     else:
                         raise KeyError("not implemented in windowed situation: " + str(k) + ": " + str(opk))
@@ -580,16 +643,26 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
                         value_name = opk.args[0].column_name
                         if value_name not in set(col_list):
                             col_list = col_list + [value_name]
+                        transform_op = opk.op
+                        try:
+                            transform_op = self.transform_op_map[transform_op]
+                        except KeyError:
+                            pass
                         subframe[k] = opframe[value_name].transform(
-                            opk.op, *transform_args
+                            transform_op, *transform_args
                         )  # Pandas transform, not data_algegra
                     elif isinstance(opk.args[0], data_algebra.expr_rep.Value):
                         value_name = data_algebra_temp_cols[str(opk.args[0].value)]
+                        transform_op = opk.op
+                        try:
+                            transform_op = self.transform_op_map[transform_op]
+                        except KeyError:
+                            pass
                         subframe[k] = opframe[value_name].transform(
-                            opk.op, *transform_args
+                            transform_op, *transform_args
                         )  # Pandas transform, not data_algegra
                     else:
-                        raise ValueError("opk must be a ColumnReference or Value")
+                        raise ValueError(f"opk must be a ColumnReference or Value ({opk})")
             # clear some temps
             for value_name in data_algebra_temp_cols.values():
                 del res[value_name]
@@ -647,14 +720,25 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
                     value_name = str(opk.args[0])
                     if isinstance(opk.args[0], data_algebra.expr_rep.Value):
                         value_name = data_algebra_temp_cols[value_name]
+                transform_op = opk.op
                 if len(opk.args) > 0:
-                    vk = res[value_name].agg(opk.op)
+                    transform_op = opk.op
+                    try:
+                        transform_op = self.transform_op_map[transform_op]
+                    except KeyError:
+                        pass
+                    vk = res[value_name].agg(transform_op)
                 else:
                     # expect and strip off initial underbar
-                    assert isinstance(opk.op, str)
-                    assert len(opk.op) > 1
-                    assert opk.op[0] == '_'
-                    vk = res["_data_table_temp_col"].agg(opk.op[1:])
+                    assert isinstance(transform_op, str)
+                    assert len(transform_op) > 1
+                    assert transform_op[0] == '_'
+                    transform_op = transform_op[1:]
+                    try:
+                        transform_op = self.transform_op_map[transform_op]
+                    except KeyError:
+                        pass
+                    vk = res["_data_table_temp_col"].agg(transform_op)
                 cols[k] = vk
         else:
             cols = {"_data_table_temp_col": res["_data_table_temp_col"].agg("sum")}
