@@ -17,7 +17,7 @@ Licence: https://github.com/lark-parser/lark/blob/master/LICENSE (MIT)
 # changes:
 # !_mul_op: "*"|"@"|"/"|"%"|"//"
 # redefined as
-# !_mul_op: "*"|"@"|"/"|"%+%"|"%?%"|"%"|"//"
+# !_mul_op: "*"|"/"|"%+%"|"%?%"|"%"|"//"|"%/%"
 # added in or_test_sym and and_test_sym
 # removed expression & and |
 
@@ -129,7 +129,7 @@ star_expr: "*" expr
 !_add_op: "+"|"-"
 !_shift_op: "<<"|">>"
 // !_mul_op: "*"|"@"|"/"|"%"|"//"
-!_mul_op: "*"|"@"|"/"|"%+%"|"%?%"|"%"|"//"
+!_mul_op: "*"|"/"|"%+%"|"%?%"|"%"|"//"|"%/%"
 // <> isn't actually a valid comparison operator in Python. It's here for the
 // sake of a __future__ import described in PEP 401 (which really works :-)
 !_comp_op: "<"|">"|"=="|">="|"<="|"<>"|"!="|"in"|"not" "in"|"is"|"is" "not"
