@@ -16,6 +16,7 @@ import data_algebra.BigQuery
 import data_algebra.PostgreSQL
 import data_algebra.MySQL
 import data_algebra.SparkSQL
+from data_algebra.sql_format_options import SQLFormatOptions
 
 from data_algebra.data_ops import *
 
@@ -79,13 +80,15 @@ def equivalent_frames(
     # leave in extra checks as this is usually used by test code
     if local_data_model is None:
         local_data_model = data_algebra.default_data_model
-    assert isinstance(a, local_data_model.pd.DataFrame)
-    assert isinstance(b, local_data_model.pd.DataFrame)
+    assert local_data_model.is_appropriate_data_instance(a)
+    assert local_data_model.is_appropriate_data_instance(b)
     if a.shape != b.shape:
         return False
     if a.shape[1] < 1:
         return True
-    a = a.reset_index(drop=True, inplace=False)
+    if a.equals(b):
+        return True
+    a = a.reset_index(drop=True, inplace=False)  # get rid of indices
     b = b.reset_index(drop=True, inplace=False)
     if not cols_case_sensitive:
         a.columns = [c.lower() for c in a.columns]
@@ -256,7 +259,7 @@ def _run_handle_experiments(
             cols_case_sensitive=cols_case_sensitive,
             check_row_order=check_row_order,
         ):
-            raise ValueError(f"{db_handle} SQL result did not match expect")
+            raise ValueError(f"{db_handle.db_model} SQL result did not match expect")
     if res_db_ops is not None:
         if not equivalent_frames(
             res_db_ops,
@@ -410,16 +413,18 @@ def check_transform_on_handles(
             for initial_commas in [True, False]:
                 for use_with in [True, False]:
                     for annotate in [True, False]:
-                        sql_format_options = data_algebra.db_model.SQLFormatOptions(
-                            use_with=use_with,
-                            annotate=annotate,
-                            initial_commas=initial_commas,
-                        )
-                        sql = db_handle.to_sql(
-                            ops, sql_format_options=sql_format_options,
-                        )
-                        assert isinstance(sql, str)
-                        sql_statements.add(sql)
+                        for use_cte_elim in [True, False]:
+                            sql_format_options = SQLFormatOptions(
+                                use_with=use_with,
+                                annotate=annotate,
+                                initial_commas=initial_commas,
+                                use_cte_elim=use_cte_elim,
+                            )
+                            sql = db_handle.to_sql(
+                                ops, sql_format_options=sql_format_options,
+                            )
+                            assert isinstance(sql, str)
+                            sql_statements.add(sql)
             if db_handle.conn is not None:
                 _run_handle_experiments(
                     db_handle=db_handle,
@@ -481,7 +486,7 @@ def check_transform(
     cols_case_sensitive: bool = False,
     check_row_order: bool = False,
     check_parse: bool = True,
-    models_to_skip: Optional[Iterable[str]] = None,
+    models_to_skip: Optional[Iterable] = None,
     valid_for_empty: bool = True,
     empty_produces_empty: bool = True,
 ) -> None:
@@ -497,7 +502,7 @@ def check_transform(
     :param cols_case_sensitive: passed to equivalent_frames()
     :param check_row_order: passed to equivalent_frames()
     :param check_parse: if True check expression parses/formats to self
-    :param models_to_skip: None or set of model names to skip testing
+    :param models_to_skip: None or set of model names or models to skip testing
     :param valid_for_empty: logical, if True perform tests on empty inputs
     :param empty_produces_empty: logical, if True assume emtpy inputs should produce empty output
     :return: nothing
@@ -522,7 +527,7 @@ def check_transform(
     db_handles = db_handles + test_dbs
 
     if models_to_skip is not None:
-        models_to_skip = set(models_to_skip)
+        models_to_skip = {str(m) for m in models_to_skip}
         db_handles = [h for h in db_handles if str(h.db_model) not in models_to_skip]
 
     caught: Optional[Any] = None
